<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da_DK">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About </source>
        <translation>Om </translation>
    </message>
    <message>
        <source>About</source>
        <translation>Om</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <source>Author</source>
        <translation>Forfatter</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Donér</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
</context>
<context>
    <name>AboutTab</name>
    <message>
        <source>Screenshot Tool</source>
        <translation>Skærmoptagelses værktøj</translation>
    </message>
    <message>
        <source>License: </source>
        <translation>Licens: </translation>
    </message>
    <message>
        <source>Please use </source>
        <translation>Brug venligst </translation>
    </message>
    <message>
        <source> to report bugs.</source>
        <translation> til rapporter fejl.</translation>
    </message>
</context>
<context>
    <name>AddWatermarkOperation</name>
    <message>
        <source>Watermark Image Required</source>
        <translation>Vandmærke billede krævet</translation>
    </message>
    <message>
        <source>Please add a Watermark Image via Options &gt; Settings &gt; Annotator &gt; Update</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AnnotationSettings</name>
    <message>
        <source>Paint Item Shadows</source>
        <translation>Mal emnets skygger</translation>
    </message>
    <message>
        <source>When enabled, paint items cast shadows.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smooth Painter Paths</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled smooths out pen and
marker paths after finished drawing.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Smooth Factor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Increasing the smooth factor will decrease
precision for pen and marker but will
make them more smooth.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text Font</source>
        <translation>Skrifttype</translation>
    </message>
    <message>
        <source>Sets the font for the Text Paint Item.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bold</source>
        <translation>Fed</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Understreget</translation>
    </message>
    <message>
        <source>Numbering Font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sets the font for the Numbering Paint Item.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Watermark Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rotate Watermark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled, Watermark will be added with a rotation of 45°</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Annotator Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ApplicationSettings</name>
    <message>
        <source>Capture screenshot at startup with default mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use Tray Icon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled will add a Tray Icon to the TaskBar if the OS Window Manager supports it.
Change requires restart.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Minimize to Tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close to Tray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Application Style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sets the application style which defines the look and feel of the GUI.
Change requires ksnip restart to take effect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Application Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Automatically copy new captures to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Auto Hide Tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Tabbar when only on Tab is used.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remember ksnip position on move and load on startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remember ksnip tool selection and load on startup</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use Tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change requires restart.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Run ksnip as single instance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enabling this option will allow only one ksnip instance to run,
all other instances started after the first will pass it&apos;s
arguments to the first and close. Changing this option requires
a new start of all instances.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Minimized to Tray</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AuthorTab</name>
    <message>
        <source>The Author:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Contributors:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Spanish Translation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Dutch Translation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Russian Translation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Norwegian Bokmål Translation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>French Translation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Polish Translation</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CanDiscardOperation</name>
    <message>
        <source>Warning - </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The capture %1%2%3 has been modified.
Do you want to save it?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CaptureModePicker</name>
    <message>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rectangular Area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Draw a rectangular area with your mouse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Last Rectangular Area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture a screenshot of the last selected rectangular area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Full Screen (All Monitors)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture full screen including all monitors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture screen where the mouse is located</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Active Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture window that currently has focus</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Window Under Cursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture that is currently under the mouse cursor</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DonateTab</name>
    <message>
        <source>Donate a Beer?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sure, you can do that</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>here</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Become a Sponsor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Also possible, </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Donations are always welcome</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HandleUploadResultOperation</name>
    <message>
        <source>Upload Successful</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload script </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> finished successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Uploaded to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to save temporary image for upload.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to start process, check path and permissions.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Process crashed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Process timed out.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Process read error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Process write error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Web error, check console output.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown process error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload Failed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HotKeySettings</name>
    <message>
        <source>Enable Global HotKeys</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HotKeys are currently supported only for Windows and X11</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture Rect Area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture Last Rect Area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture Full Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture current Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture active Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture Window under Cursor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Global HotKeys</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImageGrabberSettings</name>
    <message>
        <source>Capture mouse cursor on screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Should mouse cursor be visible on
screenshots.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Freeze Image while snipping</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled will freeze the background while
selecting a rectangular region. It also changes
the behavior of delayed screenshots, with this
option enabled the delay happens before the
snipping area is show and with the option disabled
the delay happens after the snipping area is shown.
This feature is always disabled for Wayland and always
enabled for MacOs.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show magnifying glass on snipping area</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show a magnifying glass which zooms into
the background image. This option only works
with &apos;Freeze Image while snipping&apos; enabled.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Snipping Area rulers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Horizontal and vertical lines going from
desktop edges to cursor on snipping area.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show Snipping Area position and size info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When left mouse is not pressed the position
is show, when the mouse button is pressed,
the size of the select area is shown left
and above from the captured area.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area cursor color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sets the color of the snipping area
cursor. Change requires ksnip restart to
take effect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Snipping Area cursor thickness</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sets the thickness of the snipping area
cursor. Change requires ksnip restart to
take effect.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgurHistoryDialog</name>
    <message>
        <source>Imgur History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished">Luk</translation>
    </message>
    <message>
        <source>Time Stamp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Link</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgurUploader</name>
    <message>
        <source>Upload to imgur.com finished!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Received new token, trying upload again…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Imgur token has expired, requesting new token…</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImgurUploaderSettings</name>
    <message>
        <source>Force anonymous upload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>After uploading open Imgur link in default browser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link directly to image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Always copy Imgur link to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Client ID</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Client Secret</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PIN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter imgur Pin which will be exchanged for a token.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Get PIN</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Get Token</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Imgur History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Waiting for imgur.com…</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Imgur.com token successfully updated.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Imgur.com token update error.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Base Url:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Base url that will be used for communication with Imgur.
Changing requires restart.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainToolBar</name>
    <message>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delay in seconds between triggering
and capturing screenshot.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>s</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Screen Capture to file system</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Screen Capture to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Redo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Crop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Crop Screen Capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tools</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Unable to show image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No image provided to but one was expected.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unsaved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opens printer dialog and provide option to print image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print Preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opens Print Preview dialog where the image orientation can be changed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scale Screen Capture</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Watermark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Watermark to captured image. Multiple watermarks can be added.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image Files (*.png *.jpg *.bmp)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save As...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste Embedded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Upload capture to external source</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NewCaptureNameProvider</name>
    <message>
        <source>Capture</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SaveOperation</name>
    <message>
        <source>Save As</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image Saved</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saved to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saving Image Failed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to save image to</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SaverSettings</name>
    <message>
        <source>Automatically save new captures to default location</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Prompt to save before discarding unsaved changes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remember last Save Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When enabled will overwrite the save directory stored in settings
with the latest save directory, for every save.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture save location and filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Supported Formats are JPG, PNG and BMP. If no format provided, PNG will be used as default.
Filename can contain following wildcards:
- $Y, $M, $D for date, $h, $m, $s for time, or $T for time in hhmmss format.
- Multiple consecutive # for counter. #### will result in 0001, next capture would be 0002.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saver Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture save location</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScriptUploaderSettings</name>
    <message>
        <source>Copy script output to clipboard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>After:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Only output following this string will be copied to clipboard, excluding that string.
If omitted, everything from start will be copied.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Before:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Only output before this string will be copied to clipboard, excluding that string.
If omitted, everything up to the end will be copied.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Script:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Path to script that will be called for uploading. During upload the script will be called
with the path to a temporary png file as a single argument.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select Upload Script</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Image Grabber</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Imgur Uploader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Annotator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HotKeys</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Script Uploader</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stickers</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StickerSettings</name>
    <message>
        <source>Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use Default Stickers</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sticker Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Sticker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vector Image Files (*.svg)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TrayIcon</name>
    <message>
        <source>Show Editor</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UpdateWatermarkOperation</name>
    <message>
        <source>Select Image</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UploadOperation</name>
    <message>
        <source>Upload Script Required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Please add an upload script via Options &gt; Settings &gt; Upload Script</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Capture Upload</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You are about to upload the image to an external destination, do you want to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UploaderSettings</name>
    <message>
        <source>Ask for confirmation before uploading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Uploader Type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Imgur</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Script</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Uploader</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>VersionTab</name>
    <message>
        <source>Version</source>
        <translation type="unfinished">Version</translation>
    </message>
    <message>
        <source>Build</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Using:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
